@@ -169,8 +169,9 @@ class App(tornado.web.Application):
     def init_setattr(self):
         ServicesFindet(BaseHandler, BaseModel)(self.kwargs)
         setattr(BaseModel, "uri", self.uri)
-        setattr(self, "api_schema", self.api_schema_dir)
         setattr(self, "app_config", self.kwargs)
+        setattr(BaseHandler, "api_schema", self.api_schema_dir)
+        setattr(BaseHandler, "app_config", self.kwargs)
         setattr(BaseModel, "api_schema", self.api_schema_dir)
         setattr(BaseModel, "app_config", self.kwargs)
         setattr(BaseHandler, "request_url", self.request_url)
