@@ -20,6 +20,21 @@ from lcyframe.libs.permissions import Permission
 
 class BaseHandler(RequestHandler):
     __structure__ = {}
+    app_config = {}
+    model = None
+    mongo = None
+    mysql = None
+    redis = None
+    ssdb = None
+    mq = None
+    nsq = None
+    mqtt = None
+    celery = None
+    beanstalk = None
+    qiniu = None
+    emchat = None
+    aes = None
+    graylog = None
 
     def __init__(self, application, request, **kwargs):
         self.application = application
@@ -72,19 +87,21 @@ class BaseHandler(RequestHandler):
             self.set_cors_header()
 
         if status_code == 404:
-            return self.write_failed(code=status_code, msg="Not found", name="HTTP 404")
+            logging.error("HTTP 404: URL Not Found")
+            return self.write_failed(code=status_code, msg="Not Found", name="HTTP 404")
         elif status_code == 405:
-            logging.warning("HTTP 405: Method/URL Not Allowed")
+            logging.error("HTTP 405: Method/URL Not Allowed")
             return self.write_failed(code=status_code, msg="HTTP 405: Method/URL Not Allowed", name="HTTP 405")
         elif status_code == 500:
+            logging.error(format_exc())
             error = kwargs["exc_info"][1]
-            logging.warning("时间：" + self.utils.int_to_date_string(self.utils.now(), "%Y-%m-%d %H:%M:%S"))
+            logging.error("异常时间：" + self.utils.int_to_date_string(self.utils.now(), "%Y-%m-%d %H:%M:%S"))
             if not hasattr(error, "message"):
                 message = error.args[0] if error.args else "未知错误"
+                logging.error("异常信息：" + message)
             else:
-                message = error.message
-
-            logging.warning(message)
+                logging.error("异常码：" + str(error.code))
+                logging.error("异常信息：" + error.message)
             if not hasattr(error, "code_name") or not hasattr(error, "code"):
                 return self.write_failed()
             else:
@@ -94,20 +111,22 @@ class BaseHandler(RequestHandler):
 
     def write_success(self, data=None):
         request_time = 1000.0 * self.request.request_time()
+        is_slow_request = request_time > int(self.application.app_config["wsgi"].get("slow_request_time", 1000))
+        p = self.params if hasattr(self, "params") else {}
         if self.application.app_config.get("logging_config", {}).get("level", "debug") != "debug":
-            if request_time > int(self.application.app_config["wsgi"].get("slow_request_time", 1000)):
-                logging.warning("%d %s %.2fms", self.get_status(),
-                                self._request_summary(), request_time)
+            if is_slow_request:
+                logging.warning("%d %s %.2fms", self.get_status(), self._request_summary(), request_time)
+
         if hasattr(self, "graylog"):
-            p = self.params if hasattr(self, "params") else {}
-            self.graylog.from_server(short_message="OK", code=0, host=self.request.host, request_time=int(request_time), remote_ip=self.request.remote_ip,
-                                     uri=self.request.path, params=p, method=self.request.method)
+            if self.application.app_config["graylog_config"].get("mode", 0) or is_slow_request:
+                self.graylog.from_server(short_message="OK", code=0, host=self.request.host, request_time=int(request_time), remote_ip=self.request.remote_ip,
+                                         uri=self.request.path, params=p, method=self.request.method)
         return self.write({"code": 0, "msg": "OK", "data": get_return(self, data or {})})
 
     def write_failed(self, code=1, msg="Error. unknown error", name="HTTP 500"):
         if hasattr(self, "graylog"):
             p = self.params if hasattr(self, "params") else {}
-            self.graylog.from_server(short_message=msg, code=code, track=format_exc()[-10:], host=self.request.host, header=self.request.headers._dict,
+            self.graylog.from_server(short_message=msg, code=code, track=format_exc()[-500:], host=self.request.host, header=self.request.headers._dict,
                                      remote_ip=self.request.remote_ip, uri=self.request.path, params=p, method=self.request.method)
         if name:
             self.write({"code": code, "msg": msg, "name": name, "data": None})
@@ -204,16 +223,22 @@ class BaseHandler(RequestHandler):
 class BaseModel(object):
     utils = utils
     Permission = None
+    api_error = None
+    app_config = {}
+    model = None
     mongo = None
     mysql = None
     redis = None
     ssdb = None
     mq = None
     nsq = None
+    mqtt = None
     celery = None
-    api_error = None
-    app_config = {}
-    model = None
+    beanstalk = None
+    qiniu = None
+    emchat = None
+    aes = None
+    graylog = None
 
     @classmethod
     def _parse_data(cls, d, **kwargs):
@@ -336,6 +361,7 @@ class BaseSchema(object):
 
         for d in insert_docs:
             d["create_at"] = utils.now()
+            d["update_at"] = utils.now()
             s = vars(cls())
             s.update(d)
             doc_or_docs.append(s)
@@ -751,7 +777,7 @@ class BaseSchema(object):
 
     @classmethod
     def __meta_cursor(cls, cursor, page=None, count=10, sort=dict()):
-        sort = sort.items() if type(sort) == dict else list(sort) if sort else False
+        sort = list(sort.items()) if type(sort) == dict else list(sort) if sort else False
 
         if page:
             skip = (int(page) - 1) * int(count)
